@@ -75,7 +75,7 @@ def qnwsimp(n, a, b):
 
 #=======================================================================================================================
 #
-#  ARMA CLASS
+#  ARMA_class CLASS
 #
 #_______________________________________________________________________________________________________________________
 class ARMA:
@@ -160,7 +160,7 @@ class ARMA:
         if self.is_stationary:
             return self.sigma2 * (self.MApower(w) / self.ARpower(w)) / (2 * np.pi)
         else:
-            warn('This ARMA(%d,%d) process is not stationary' % (self.p, self.q))
+            warn('This ARMA_class(%d,%d) process is not stationary' % (self.p, self.q))
             return np.nan + np.zeros_like(w)
 
 
@@ -373,7 +373,7 @@ app.layout = html.Div(children=[
             style={'textAlign': 'center', 'color': colors['text']}),
     html.P(id='estimated',
             style={'textAlign': 'center', 'color': colors['text']}),
-    html.Div(children=[html.H4("ARMA Parameters"),
+    html.Div(children=[html.H4("ARMA_class Parameters"),
                        html.Table(children=[
                            app_parameter_row('c', 'c', 'number', 0),
                            app_parameter_row('AR', 'AR', 'text', ''),
@@ -397,7 +397,7 @@ app.layout = html.Div(children=[
                                                                *app_parameter('q', 'q', 'text', '0', '5')])]),
                        html.Hr(),
                        html.Button('PLOT', id='execute',style={'textAlign': 'center', 'backgroundColor': colors['buttons']}),
-                       html.P('ARMA PROCESS DEMO', style={'textAlign': 'center', 'color': colors['text'],'marginTop':500}),
+                       html.P('ARMA_class PROCESS DEMO', style={'textAlign': 'center', 'color': colors['text'],'marginTop':500}),
                        ],
              style={'textAlign': 'center', 'color': colors['controls'], 'width': '20%', 'display': 'inline-block'}),
 
