@@ -16,8 +16,9 @@ Randall Romero Aguilar, 2016-2021
 #import .constants
 #import .common_components
 from .captura import read_IFS
-from .demo_ARMA import ARMA_demo
-from .demo_Solow import Solow_demo
-from .demo_Markov import Markov_demo
-from .demo_filters import filters_demo
+from .demo_ARMA import ARMA
+from .demo_Solow import Solow
+from .demo_Markov import Markov
+from .demo_filters import filters
+from .demo_BoxJenkins import BoxJenkins
 
