@@ -1,7 +1,7 @@
 """
 demo_ARMA: Module for learning about  ARMA processes
 
-This module provides a single function, ARMA_demo(), which creates a dash consisting of 7 plots to study the
+This module provides a single function, ARMA(), which creates a dash consisting of 7 plots to study the
 theoretical properties of ARMA(p, q) process, as well as their estimated counterparts. The plots display
     1. a simulated sample
     2. autocorrelations
@@ -124,17 +124,17 @@ def add_polar_scatter(fig, roots, name, ms=16):
 
 #=======================================================================================================================
 #
-#  ARMA CLASS
+#  ARMA_class CLASS
 #
 #_______________________________________________________________________________________________________________________
-class ARMA(ArmaProcess):
+class ARMA_class(ArmaProcess):
     """
     A class to represent stationary ARMA processes
     """
 
     def __init__(self, c=0, phi=None, theta=None, sigma2=1.0, nobs=120):
         """
-        Making  a new ARMA object to represent $y_t = c + phi y_{t-lags} + e_t + theta e_{t- lags}$
+        Making  a new ARMA_class object to represent $y_t = c + phi y_{t-lags} + e_t + theta e_{t- lags}$
 
         :param c:  float, intercept
         :param phi: list-like, autorregresive coefficients
@@ -237,7 +237,7 @@ class ARMA(ArmaProcess):
             self.estimates = {'c': res.params[0]}
             self.estimates['phi'] = res.arparams if p else None
             self.estimates['theta'] = res.maparams if q else None
-            self.estimates['repr'] = str(ARMA(self.estimates['c'], self.estimates['phi'], self.estimates['theta']))
+            self.estimates['repr'] = str(ARMA_class(self.estimates['c'], self.estimates['phi'], self.estimates['theta']))
             self.estimates['fitted'] = pd.Series(res.fittedvalues)
             self.estimates['arroots'] = np.array([1/x for x in res.arroots])
             self.estimates['maroots'] = np.array([1 / x for x in res.maroots])
@@ -446,9 +446,9 @@ class ARMA(ArmaProcess):
         df = pd.DataFrame({'actual':self.impulse_response(horizon)})
 
         if self.show_estimates and self.estimated:
-            df['estimated'] = ARMA(self.estimates['c'],
-                                   self.estimates['phi'],
-                                   self.estimates['theta']).impulse_response(horizon)
+            df['estimated'] = ARMA_class(self.estimates['c'],
+                                         self.estimates['phi'],
+                                         self.estimates['theta']).impulse_response(horizon)
 
 
         fig = px.bar(df,
@@ -539,7 +539,7 @@ app.layout = html.Div(children=[
                  dcc.Graph(id='plot-ma-roots',
                            style={'width': '30%', 'float': 'left', 'display': 'inline-block'}),
              ]),
-    make_bottom_banner('macrodemos.ARMA_demo( )', width=20)
+    make_bottom_banner('macrodemos.ARMA( )', width=20)
 ],
 style={'backgroundColor': colors['background']})
 
@@ -573,7 +573,7 @@ style={'backgroundColor': colors['background']})
 def update_ARMA_parameters(n_clicks, c, phi, theta, sigma2, periods, lags, horizon, showestimates, p, q):
     phi = validate_lists_of_values(phi)
     theta = validate_lists_of_values(theta)
-    Y = ARMA(c, phi, theta, sigma2, periods)
+    Y = ARMA_class(c, phi, theta, sigma2, periods)
     Y.sample(int(periods) + 1)
     style = {'textAlign': 'center', 'color': colors['text'] if Y.isstationary else 'red'}
     Y.show_estimates = (showestimates == 'Yes')
@@ -604,7 +604,7 @@ def update_ARMA_parameters(n_clicks, c, phi, theta, sigma2, periods, lags, horiz
 def show_pq_options(showestimates, phi, theta):
     phi = validate_lists_of_values(phi)
     theta = validate_lists_of_values(theta)
-    Y = ARMA(0, phi, theta, 1.0)
+    Y = ARMA_class(0, phi, theta, 1.0)
     p, q = Y.p, Y.q
     children = [html.Tr([*app_parameter('p', 'p', 'text', p, '4'),
                         *app_parameter('q', 'q', 'text', q, '4')],
@@ -624,14 +624,16 @@ def show_pq_options(showestimates, phi, theta):
 
 
 
-def ARMA_demo(colab=False):
+def ARMA(colab=False):
     if colab:
         app.run_server(mode='external')
     else:
         webbrowser.open('http://127.0.0.1:8050/')
         app.run_server(debug=False)
 
+ARMA_demo = ARMA  # kept for backward compatibility
+
 
 if __name__ == '__main__':
-    ARMA_demo()
+    ARMA()
 
