@@ -335,7 +335,7 @@ app.layout = html.Div(children=[
                          ),
              ]), # end of Tabs
              ]),
-    make_bottom_banner("macrodemos.Solow_demo( )")
+    make_bottom_banner("macrodemos.Solow( )")
 ],
     style={'backgroundColor': colors['background']})
 
@@ -399,12 +399,15 @@ def update_Solow_parameters(n_clicks,T, α, δ, n, A, s, α1, δ1, n1, A1, s1):
 
 
 
-def Solow_demo(colab=False):
+def Solow(colab=False):
     if colab:
         app.run_server(mode='external')
     else:
         webbrowser.open('http://127.0.0.1:8050/')
         app.run_server(debug=False)
 
+
+Solow_demo = Solow # kept for backward compatibility
+
 if __name__ == '__main__':
-    Solow_demo()
\ No newline at end of file
+    Solow()
\ No newline at end of file
